summaryrefslogtreecommitdiffstats
path: root/juk/keydialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/keydialog.h')
-rw-r--r--juk/keydialog.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/juk/keydialog.h b/juk/keydialog.h
index 87979302..09c4853a 100644
--- a/juk/keydialog.h
+++ b/juk/keydialog.h
@@ -32,7 +32,7 @@ public:
/**
* Constructs a KeyDialog called @p name as a child of @p parent.
*/
- KeyDialog(KGlobalAccel *keys, KActionCollection *actionCollection, TQWidget *parent = 0, const char* name = 0);
+ KeyDialog(TDEGlobalAccel *keys, KActionCollection *actionCollection, TQWidget *parent = 0, const char* name = 0);
/**
* Destructor. Deletes all resources used by a KeyDialog object.
@@ -44,13 +44,13 @@ public:
* accelerators and actions. It behaves essentially like the functions
* in KKeyDialog.
*/
- static int configure(KGlobalAccel *keys, KActionCollection *actionCollection, TQWidget *parent = 0);
+ static int configure(TDEGlobalAccel *keys, KActionCollection *actionCollection, TQWidget *parent = 0);
/**
* This is a member function, provided to create a global accelerator with
* standard keys. It behaves like the function in KGlobalAccel.
*/
- static void insert(KGlobalAccel *keys, const TQString &action, const TQString &label,
+ static void insert(TDEGlobalAccel *keys, const TQString &action, const TQString &label,
const TQObject *objSlot, const char *methodSlot);
private:
@@ -65,7 +65,7 @@ private:
KShortcut shortcut[3][2];
};
- void newDialog(KGlobalAccel *keys, KActionCollection *actionCollection, int selectedButton = 0);
+ void newDialog(TDEGlobalAccel *keys, KActionCollection *actionCollection, int selectedButton = 0);
int configure();
private slots:
@@ -74,7 +74,7 @@ private slots:
private:
KActionCollection *m_actionCollection;
- KGlobalAccel *m_keys;
+ TDEGlobalAccel *m_keys;
KKeyChooser *m_pKeyChooser;
TQHButtonGroup *m_group;
TQWidgetStack *m_widgetStack;
@@ -44,13 +44,13 @@ public:
/**
* This is a member function, provided to create a global accelerator with
- * standard keys. It behaves like the function in KGlobalAccel.
+ * standard keys. It behaves like the function in TDEGlobalAccel.
*/